@@ -211,14 +211,14 @@ var NAVTREEINDEX =
 "LREADME.html",
 "encoder_guide.html#architecture_enc_gf_structure",
 "group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38",
-"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca7cbf0a1ff28bf7c460f6d86d63b30842",
-"group__tpl__modelling.html#gacb25270842c5ab92d1d90a211df955e5",
-"structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb",
-"structCommonTileParams.html#a68c8e416df2344d1338ebc6959651b0d",
-"structMB__MODE__INFO.html#a8552e37deea204df2caff7aa688f8ccf",
-"structRestorationUnitInfo.html#ac0f1e8bf804a5db5a6b38027e9bdb4f4",
-"structaom__ext__part__funcs.html#a00b5dea45726cf43a0407cbd7d09b907",
-"structmacroblock.html#a22c8a3380f06cf7061181e1ba5de5d5a"
+"group__codec.html#ggaaae61e0f8663e6137f1e228757248e7ca413c6090fa855359106e32fbd2b5f668",
+"group__tpl__modelling.html#ga3d123b0f3781dcb06c5f4d053ac3655b",
+"structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f",
+"structCommonQuantParams.html#ae6b10a492cbf8dd0501129c7d264ee6d",
+"structMB__MODE__INFO.html#a13f1a883e73c4b721c2212d0416b3967",
+"structRestorationInfo.html#a6b8daa3388a9cacec495eb2d8ab88436",
+"structaom__codec__enc__cfg.html#ae55d1533084ea0090588dc1187baffb5",
+"structinter__modes__info.html#afa119f92044ae1a737bab446bade8c88"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
