@@ -1,13 +1,15 @@
 var NAVTREEINDEX4 =
 {
+"group__tpl__modelling.html#ga3d123b0f3781dcb06c5f4d053ac3655b":[12,2,0,3,0],
 "group__tpl__modelling.html#gacb25270842c5ab92d1d90a211df955e5":[12,2,0,3,1],
 "group__transform__search.html":[12,2,4],
-"group__transform__search.html#ga4bdb6bc7b2510fc58a4e63212e811412":[12,2,4,1],
-"group__transform__search.html#ga6de2388a03e84841b43096d324e3ac26":[12,2,4,3],
-"group__transform__search.html#ga96f1b74712969cad39e8759642341ea3":[12,2,4,2],
-"group__transform__search.html#gaaad15ac6f5882d95c5daded8b167841c":[12,2,4,4],
-"group__transform__search.html#gab98eb8666e56c4f697af7e04e9ed8759":[12,2,4,5],
-"group__transform__search.html#gae30648a789cd8ef5cb98e0210db2371f":[12,2,4,0],
+"group__transform__search.html#ga4bdb6bc7b2510fc58a4e63212e811412":[12,2,4,2],
+"group__transform__search.html#ga6de2388a03e84841b43096d324e3ac26":[12,2,4,4],
+"group__transform__search.html#ga7986a23ed0fddc3b3b8c504e84b8ac5a":[12,2,4,0],
+"group__transform__search.html#ga96f1b74712969cad39e8759642341ea3":[12,2,4,3],
+"group__transform__search.html#gaaad15ac6f5882d95c5daded8b167841c":[12,2,4,5],
+"group__transform__search.html#gab98eb8666e56c4f697af7e04e9ed8759":[12,2,4,6],
+"group__transform__search.html#gae30648a789cd8ef5cb98e0210db2371f":[12,2,4,1],
 "group__two__pass__algo.html":[12,2,0,4],
 "group__two__pass__algo.html#ga737bbff8d05e931b73b4321a0fa35d0e":[12,2,0,4,0],
 "group__variance__partition.html":[12,2,11],
@@ -161,16 +163,18 @@ var NAVTREEINDEX4 =
 "structAV1EncAllIntraMultiThreadInfo.html#a92d1ac96767ce33c38ddd1975d6f3cb0":[13,0,44,3],
 "structAV1EncRowMultiThreadInfo.html":[13,0,46],
 "structAV1EncRowMultiThreadInfo.html#a025fcc14804ab0cc9473132b0c137b45":[13,0,46,6],
-"structAV1EncRowMultiThreadInfo.html#a09006c90727207130513fc54a48457ad":[13,0,46,7],
+"structAV1EncRowMultiThreadInfo.html#a09006c90727207130513fc54a48457ad":[13,0,46,9],
 "structAV1EncRowMultiThreadInfo.html#a213a5e74fa6a18d962ce9f02d239c4d0":[13,0,46,1],
+"structAV1EncRowMultiThreadInfo.html#a3c5e8424052296ef7f41fb498c33bbc1":[13,0,46,8],
 "structAV1EncRowMultiThreadInfo.html#a3f2230694d5d397932846fa1f954100e":[13,0,46,3],
 "structAV1EncRowMultiThreadInfo.html#a6cc17f3d021b76ca9b9a31c5dfd27ca3":[13,0,46,4],
-"structAV1EncRowMultiThreadInfo.html#a7c76b9cb599ff702d8bfd006ce24bd7f":[13,0,46,10],
-"structAV1EncRowMultiThreadInfo.html#a86644ff077b93cf17b8b513f290f26f5":[13,0,46,8],
+"structAV1EncRowMultiThreadInfo.html#a7c76b9cb599ff702d8bfd006ce24bd7f":[13,0,46,12],
+"structAV1EncRowMultiThreadInfo.html#a86644ff077b93cf17b8b513f290f26f5":[13,0,46,10],
+"structAV1EncRowMultiThreadInfo.html#a8bd7d465b2dfd296d37de307462274ea":[13,0,46,7],
 "structAV1EncRowMultiThreadInfo.html#aa10709bc0f6142a12c251eecaa4b314d":[13,0,46,0],
 "structAV1EncRowMultiThreadInfo.html#ab27d0af6d3f8d8d41b4fede58b34568f":[13,0,46,2],
 "structAV1EncRowMultiThreadInfo.html#abb182b4a6ad3e5cbaaebe590d5fef37d":[13,0,46,5],
-"structAV1EncRowMultiThreadInfo.html#afc6fec4a038c014edfc197040ce1b95a":[13,0,46,9],
+"structAV1EncRowMultiThreadInfo.html#afc6fec4a038c014edfc197040ce1b95a":[13,0,46,11],
 "structAV1EncRowMultiThreadSync.html":[13,0,47],
 "structAV1EncRowMultiThreadSync.html#a2148918de3031f58c1963944dd4c7a06":[13,0,47,5],
 "structAV1EncRowMultiThreadSync.html#a27dd9c10fa352ad6d8786ea7f93b1c60":[13,0,47,3],
@@ -186,68 +190,64 @@ var NAVTREEINDEX4 =
 "structAV1EncoderConfig.html#aa7ee8fa3d9aba1bcc66fa53e67f6f431":[13,0,45,4],
 "structAV1EncoderConfig.html#af115e9bf7e78e78979373b69433f6627":[13,0,45,0],
 "structAV1EncoderConfig.html#af52aa21eb45f6e5034365352accb6a92":[13,0,45,3],
+"structAV1LrPickStruct.html":[13,0,48],
+"structAV1LrPickStruct.html#a7b15b25f1df0a4d76ab2d245070c5256":[13,0,48,0],
+"structAV1LrPickStruct.html#afda36c668c5b5b41aeb6a3689803fc5f":[13,0,48,1],
 "structAV1__COMP.html":[13,0,37],
-"structAV1__COMP.html#a01c7acc7ea64292b9563d4b8dc7d8fb3":[13,0,37,98],
-"structAV1__COMP.html#a032b8d30bbb0868fb90c519400d8d388":[13,0,37,61],
-"structAV1__COMP.html#a044d3dfed6b8921cd7d74dee128d987e":[13,0,37,86],
-"structAV1__COMP.html#a04e419d46527a4ffe5bd7151570a7c03":[13,0,37,60],
-"structAV1__COMP.html#a0605ca1d559b9566e13aa8d2d2e55284":[13,0,37,71],
+"structAV1__COMP.html#a01c7acc7ea64292b9563d4b8dc7d8fb3":[13,0,37,101],
+"structAV1__COMP.html#a032b8d30bbb0868fb90c519400d8d388":[13,0,37,62],
+"structAV1__COMP.html#a044d3dfed6b8921cd7d74dee128d987e":[13,0,37,88],
+"structAV1__COMP.html#a04e419d46527a4ffe5bd7151570a7c03":[13,0,37,61],
+"structAV1__COMP.html#a0605ca1d559b9566e13aa8d2d2e55284":[13,0,37,73],
 "structAV1__COMP.html#a060badd4366bf3a270597d89e0b1a6cb":[13,0,37,18],
-"structAV1__COMP.html#a0625521a3d2ec6126e96f7539b6bc17b":[13,0,37,111],
-"structAV1__COMP.html#a063d56623dcab7e26974036303ef012e":[13,0,37,102],
-"structAV1__COMP.html#a066a671f4995bbcf08b2110105391195":[13,0,37,55],
-"structAV1__COMP.html#a0ac239b9892a1799eda25582b402430e":[13,0,37,81],
+"structAV1__COMP.html#a0625521a3d2ec6126e96f7539b6bc17b":[13,0,37,114],
+"structAV1__COMP.html#a063d56623dcab7e26974036303ef012e":[13,0,37,105],
+"structAV1__COMP.html#a066a671f4995bbcf08b2110105391195":[13,0,37,56],
+"structAV1__COMP.html#a0ac239b9892a1799eda25582b402430e":[13,0,37,83],
 "structAV1__COMP.html#a0ee379148254c9d67fcf13ab0038bfa4":[13,0,37,12],
-"structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6":[13,0,37,114],
-"structAV1__COMP.html#a11fd423b6ca0324129bec05b69f80162":[13,0,37,43],
-"structAV1__COMP.html#a21089e9068a35e00fd998812430b5fa5":[13,0,37,49],
-"structAV1__COMP.html#a25f6a4b1abb3966d77be127dcd8b6476":[13,0,37,35],
-"structAV1__COMP.html#a26de3eb8d7f7d75083c364f754507562":[13,0,37,76],
-"structAV1__COMP.html#a26df07c85b5dc42b04519f478d90e97f":[13,0,37,44],
-"structAV1__COMP.html#a284a0ce79fc6c8e18d3b8c592b0d6da9":[13,0,37,96],
-"structAV1__COMP.html#a284dd9a2a0f4d09930197bc78d5c1209":[13,0,37,93],
-"structAV1__COMP.html#a28956d8f775c173f7bd76e92a459853c":[13,0,37,54],
-"structAV1__COMP.html#a299a82348f6f2e0b1cf7d90940a8f371":[13,0,37,29],
-"structAV1__COMP.html#a2a451884130382a33642dd88e7e4a426":[13,0,37,70],
-"structAV1__COMP.html#a2a58033f237baf3237ae7859e0397ad3":[13,0,37,92],
-"structAV1__COMP.html#a30c0d235c498e05247be568b93b98081":[13,0,37,89],
-"structAV1__COMP.html#a37618681daa2a234bbfb424ce6d22f5b":[13,0,37,39],
+"structAV1__COMP.html#a1190b8a5f0c524ff122e693207e6a9b6":[13,0,37,117],
+"structAV1__COMP.html#a11fd423b6ca0324129bec05b69f80162":[13,0,37,44],
+"structAV1__COMP.html#a21089e9068a35e00fd998812430b5fa5":[13,0,37,50],
+"structAV1__COMP.html#a25f6a4b1abb3966d77be127dcd8b6476":[13,0,37,36],
+"structAV1__COMP.html#a26de3eb8d7f7d75083c364f754507562":[13,0,37,78],
+"structAV1__COMP.html#a26df07c85b5dc42b04519f478d90e97f":[13,0,37,45],
+"structAV1__COMP.html#a284a0ce79fc6c8e18d3b8c592b0d6da9":[13,0,37,99],
+"structAV1__COMP.html#a284dd9a2a0f4d09930197bc78d5c1209":[13,0,37,96],
+"structAV1__COMP.html#a28956d8f775c173f7bd76e92a459853c":[13,0,37,55],
+"structAV1__COMP.html#a299a82348f6f2e0b1cf7d90940a8f371":[13,0,37,30],
+"structAV1__COMP.html#a2a451884130382a33642dd88e7e4a426":[13,0,37,72],
+"structAV1__COMP.html#a2a58033f237baf3237ae7859e0397ad3":[13,0,37,95],
+"structAV1__COMP.html#a30c0d235c498e05247be568b93b98081":[13,0,37,92],
+"structAV1__COMP.html#a37618681daa2a234bbfb424ce6d22f5b":[13,0,37,40],
 "structAV1__COMP.html#a391735210b755ea3e9de4777dd10965b":[13,0,37,9],
-"structAV1__COMP.html#a3a1d855f2d5488284688433c8d7bdc86":[13,0,37,90],
-"structAV1__COMP.html#a3a5748228c0070093a482972587f43e5":[13,0,37,106],
-"structAV1__COMP.html#a3b3aa4af7d870ee595dbe487c37d3950":[13,0,37,78],
-"structAV1__COMP.html#a3bd63a7c3fce5555319fc797beae8849":[13,0,37,30],
-"structAV1__COMP.html#a3f3c93cc1e7ce42de06a8aae22397fcf":[13,0,37,82],
-"structAV1__COMP.html#a444d81f3fcfdd6a4205aa4318b7cafca":[13,0,37,33],
-"structAV1__COMP.html#a473c02eb07f88a9bcebeaece5c5fe0cc":[13,0,37,26],
-"structAV1__COMP.html#a4a7cab775d531af4ba9f1eaeccd34a58":[13,0,37,42],
-"structAV1__COMP.html#a4ac2ac3d57f1620126ab34d1f19f2943":[13,0,37,40],
-"structAV1__COMP.html#a4ca11c36b5bab99d6240752ff37a89a3":[13,0,37,73],
-"structAV1__COMP.html#a4f0c3420fc582c1e40452334689eb127":[13,0,37,62],
-"structAV1__COMP.html#a4fc82f94416481dd23593999de64e369":[13,0,37,31],
+"structAV1__COMP.html#a3a1d855f2d5488284688433c8d7bdc86":[13,0,37,93],
+"structAV1__COMP.html#a3a5748228c0070093a482972587f43e5":[13,0,37,109],
+"structAV1__COMP.html#a3b3aa4af7d870ee595dbe487c37d3950":[13,0,37,80],
+"structAV1__COMP.html#a3bd63a7c3fce5555319fc797beae8849":[13,0,37,31],
+"structAV1__COMP.html#a3f3c93cc1e7ce42de06a8aae22397fcf":[13,0,37,84],
+"structAV1__COMP.html#a444d81f3fcfdd6a4205aa4318b7cafca":[13,0,37,34],
+"structAV1__COMP.html#a473c02eb07f88a9bcebeaece5c5fe0cc":[13,0,37,27],
+"structAV1__COMP.html#a4a7cab775d531af4ba9f1eaeccd34a58":[13,0,37,43],
+"structAV1__COMP.html#a4ac2ac3d57f1620126ab34d1f19f2943":[13,0,37,41],
+"structAV1__COMP.html#a4ca11c36b5bab99d6240752ff37a89a3":[13,0,37,75],
+"structAV1__COMP.html#a4f0c3420fc582c1e40452334689eb127":[13,0,37,63],
+"structAV1__COMP.html#a4fc82f94416481dd23593999de64e369":[13,0,37,32],
 "structAV1__COMP.html#a523f84e04ce020b292bf61b256ae6846":[13,0,37,20],
-"structAV1__COMP.html#a54cb83d48c9dce7ddc82931e448bc82e":[13,0,37,113],
-"structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb":[13,0,37,21],
-"structAV1__COMP.html#a58ea35e30c39019ec39bca542d4d7d64":[13,0,37,32],
+"structAV1__COMP.html#a54cb83d48c9dce7ddc82931e448bc82e":[13,0,37,116],
+"structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb":[13,0,37,22],
+"structAV1__COMP.html#a58ea35e30c39019ec39bca542d4d7d64":[13,0,37,33],
+"structAV1__COMP.html#a5d82be59e7badc649655a7f281b017c2":[13,0,37,89],
 "structAV1__COMP.html#a5dd4bce670a858752380e59d8d8daaf9":[13,0,37,6],
-"structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f":[13,0,37,48],
-"structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece":[13,0,37,37],
-"structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc":[13,0,37,22],
-"structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65":[13,0,37,45],
+"structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f":[13,0,37,49],
+"structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece":[13,0,37,38],
+"structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc":[13,0,37,23],
+"structAV1__COMP.html#a630c1c37c763287c2a68cb64be0bbc65":[13,0,37,46],
 "structAV1__COMP.html#a683b6b6df2109e6301e61b07678cfa12":[13,0,37,8],
 "structAV1__COMP.html#a6c5ff3b8df382c108abbb290502d6242":[13,0,37,7],
-"structAV1__COMP.html#a6dc37728067978a7637f76c6b7c41979":[13,0,37,69],
-"structAV1__COMP.html#a6e6ceda86270005d35ace1b04ec593bf":[13,0,37,95],
-"structAV1__COMP.html#a70a2523a80b95533cb00052e485cdc9a":[13,0,37,59],
+"structAV1__COMP.html#a6dc37728067978a7637f76c6b7c41979":[13,0,37,70],
+"structAV1__COMP.html#a6e6ceda86270005d35ace1b04ec593bf":[13,0,37,98],
+"structAV1__COMP.html#a6f20ccca66ccc28bea06f8452311a2f7":[13,0,37,21],
+"structAV1__COMP.html#a70a2523a80b95533cb00052e485cdc9a":[13,0,37,60],
 "structAV1__COMP.html#a7305c275e154639e8e70a7cfefcce324":[13,0,37,3],
-"structAV1__COMP.html#a79be536fcf6a3d04be9c6c7a838e2421":[13,0,37,80],
-"structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f":[13,0,37,67],
-"structAV1__COMP.html#a7c2391b88acf55f27fee48eee1d9deba":[13,0,37,57],
-"structAV1__COMP.html#a7c68dc43bf3c85698d913e3c9968b40a":[13,0,37,25],
-"structAV1__COMP.html#a7e0661a8322b19a27c9969d2898ed858":[13,0,37,24],
-"structAV1__COMP.html#a7ee7e00e3423b19eac935c9a27c14a8d":[13,0,37,68],
-"structAV1__COMP.html#a7f8997078cd563ed82f37e0b04e00b91":[13,0,37,14],
-"structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27":[13,0,37,105],
-"structAV1__COMP.html#a8172b1a8dc8d210fa745138938874fb7":[13,0,37,41],
-"structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb":[13,0,37,65]
+"structAV1__COMP.html#a79be536fcf6a3d04be9c6c7a838e2421":[13,0,37,82]
 };
