@@ -21,6 +21,7 @@ var structAV1__COMP =
     [ "skip_tpl_setup_stats", "structAV1__COMP.html#a060badd4366bf3a270597d89e0b1a6cb", null ],
     [ "tpl_rdmult_scaling_factors", "structAV1__COMP.html#aaa416562780c42ed8fbc439a8e033f59", null ],
     [ "tf_ctx", "structAV1__COMP.html#a523f84e04ce020b292bf61b256ae6846", null ],
+    [ "cdef_search_ctx", "structAV1__COMP.html#a6f20ccca66ccc28bea06f8452311a2f7", null ],
     [ "force_intpel_info", "structAV1__COMP.html#a5733fdde1a696d314fc0ce412b91f8fb", null ],
     [ "scaled_ref_buf", "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc", null ],
     [ "last_show_frame_buf", "structAV1__COMP.html#a9c4957c740b2c95513d7af9ed2999211", null ],
@@ -70,6 +71,7 @@ var structAV1__COMP =
     [ "intrabc_used", "structAV1__COMP.html#a79d3369ac3e0d4a9461c133a285a417f", null ],
     [ "prune_ref_frame_mask", "structAV1__COMP.html#a7ee7e00e3423b19eac935c9a27c14a8d", null ],
     [ "lr_ctxt", "structAV1__COMP.html#a6dc37728067978a7637f76c6b7c41979", null ],
+    [ "pick_lr_ctxt", "structAV1__COMP.html#aa2c5ad94c8bc0d7da5a4354bbe68301b", null ],
     [ "film_grain_table", "structAV1__COMP.html#a2a451884130382a33642dd88e7e4a426", null ],
     [ "denoise_and_model", "structAV1__COMP.html#a0605ca1d559b9566e13aa8d2d2e55284", null ],
     [ "interp_search_flags", "structAV1__COMP.html#abdbb43940e22262999e72bccf44fb1a2", null ],
